@@ -1,7 +1,7 @@
 package Bencher::Formatter::RoundNumbers;
 
-our $DATE = '2016-08-24'; # DATE
-our $VERSION = '1.020'; # VERSION
+our $DATE = '2016-08-26'; # DATE
+our $VERSION = '1.021'; # VERSION
 
 use 5.010001;
 use strict;
@@ -62,7 +62,7 @@ sub munge_result {
         # they are not time measurement, but we do want to round it when it has
         # been divided when converting unit to kB, MB, etc.
         for my $col (keys %$rit) {
-            if ($col =~ /^(result|proc_\w+|proc)_size$/ && $rit->{$col} != int($rit->{$col})) {
+            if ($col =~ /^(result|proc_\w+|proc|arg_\w+)_size$/ && $rit->{$col} != int($rit->{$col})) {
                 $rit->{$col} = $code_fmt->(
                     $num_significant_digits, $rit->{$col});
             }
@@ -85,7 +85,7 @@ Bencher::Formatter::RoundNumbers - Round numbers (rate, time) to certain signifi
 
 =head1 VERSION
 
-This document describes version 1.020 of Bencher::Formatter::RoundNumbers (from Perl distribution Bencher-Backend), released on 2016-08-24.
+This document describes version 1.021 of Bencher::Formatter::RoundNumbers (from Perl distribution Bencher-Backend), released on 2016-08-26.
 
 =for Pod::Coverage .*
 
